@@ -1,10 +1,22 @@
-/* $Id: translate.cc,v 1.4 2004/11/01 04:35:57 nuffer Exp $ */
+/* $Id: translate.cc 733 2007-05-02 20:19:32Z helly $ */
 #include "globals.h"
 
 namespace re2c
 {
 
-uchar asc2asc[256] =
+static const char * sHex = "0123456789ABCDEF";
+
+char octCh(uint c)
+{
+	return '0' + c % 8;
+}
+
+char hexCh(uint c)
+{
+	return sHex[c & 0x0F];
+}
+
+uint asc2asc[256] =
     {
         0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
         0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17, 0x18, 0x19, 0x1a, 0x1b, 0x1c, 0x1d, 0x1e, 0x1f,
@@ -24,10 +36,10 @@ uchar asc2asc[256] =
         0xf0, 0xf1, 0xf2, 0xf3, 0xf4, 0xf5, 0xf6, 0xf7, 0xf8, 0xf9, 0xfa, 0xfb, 0xfc, 0xfd, 0xfe, 0xff
     };
 
-uchar *xlat = asc2asc;
-uchar *talx = asc2asc;
+uint *xlat = asc2asc;
+uint *talx = asc2asc;
 
-uchar asc2ebc[256] =
+uint asc2ebc[256] =
     { /* Based on ISO 8859/1 and Code Page 37 */
         0x00, 0x01, 0x02, 0x03, 0x37, 0x2d, 0x2e, 0x2f, 0x16, 0x05, 0x25, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
         0x10, 0x11, 0x12, 0x13, 0x3c, 0x3d, 0x32, 0x26, 0x18, 0x19, 0x3f, 0x27, 0x1c, 0x1d, 0x1e, 0x1f,
@@ -47,7 +59,7 @@ uchar asc2ebc[256] =
         0x8c, 0x49, 0xcd, 0xce, 0xcb, 0xcf, 0xcc, 0xe1, 0x70, 0xdd, 0xde, 0xdb, 0xdc, 0x8d, 0xae, 0xdf
     };
 
-uchar ebc2asc[256] =
+uint ebc2asc[256] =
     { /* Based on ISO 8859/1 and Code Page 37 */
         0x00, 0x01, 0x02, 0x03, 0x9c, 0x09, 0x86, 0x7f, 0x97, 0x8d, 0x8e, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f,
         0x10, 0x11, 0x12, 0x13, 0x9d, 0x85, 0x08, 0x87, 0x18, 0x19, 0x92, 0x8f, 0x1c, 0x1d, 0x1e, 0x1f,
@@ -68,4 +80,3 @@ uchar ebc2asc[256] =
     };
 
 } // end namespace re2c
-
